Crate dropshot_api_manager

Crate dropshot_api_manager 

OpenAPI manager for Dropshot.

This tool manages OpenAPI documents corresponding to Dropshot API traits. For more information, see the README.

Modules

test_util
Test utilities for the Dropshot API manager.

Structs

App
Manage OpenAPI documents for this repository.
Environment
Configuration for the Dropshot API manager.
ManagedApi
Describes an API managed by the Dropshot API manager.
ManagedApiConfig
Describes an API managed by the Dropshot API manager.
ManagedApis
Describes the Rust-defined configuration for all of the APIs managed by this tool.

Constants

FAILURE_EXIT_CODE
Exit code which indicates that one or more failures occurred.
NEEDS_UPDATE_EXIT_CODE
Exit code which indicates that local files are out-of-date.