pub struct Environment { /* private fields */ }Expand description
Configuration for the Dropshot API manager.
This struct describes various properties of the environment the API manager is running within, such as the command to invoke the OpenAPI manager, and the repository root directory. For the full list of properties, see the methods on this struct.
Implementations
Sourceimpl Environment
impl Environment
Sourcepub fn new(
command: impl Into<String>,
repo_root: impl Into<Utf8PathBuf>,
default_openapi_dir: impl Into<Utf8PathBuf>,
) -> Result<Self>
pub fn new( command: impl Into<String>, repo_root: impl Into<Utf8PathBuf>, default_openapi_dir: impl Into<Utf8PathBuf>, ) -> Result<Self>
Creates a new environment with:
- the command to invoke the OpenAPI manager (e.g.
"cargo openapi"or"cargo xtask openapi") - the provided Git repository root
- the default OpenAPI directory as a relative path within the repository root
Returns an error if repo_root is not an absolute path or
default_openapi_dir is not a relative path.
Sourcepub fn with_default_git_branch(self, branch: impl Into<String>) -> Self
pub fn with_default_git_branch(self, branch: impl Into<String>) -> Self
Sets the default Git upstream and branch name.
By default, this is origin/main, but it can be set to any valid Git
remote and branch name separated by a forward slash, e.g.
origin/master or upstream/dev.
For individual commands, this can be overridden through the
--blessed-from-git argument, or the OPENAPI_MGR_BLESSED_FROM_GIT
environment variable.