ManagedApi

Struct ManagedApi 

pub struct ManagedApi { /* private fields */ }
Describes an API managed by the Dropshot API manager.

This type is typically created from a ManagedApiConfig and can be further configured using builder methods before being passed to ManagedApis::new.

Implementations

Source

impl ManagedApi

pub fn ident(&self) -> &ApiIdent

Returns the API identifier.

pub fn versions(&self) -> &Versions

Returns the API versions.

pub fn title(&self) -> &'static str

Returns the API title.

pub fn metadata(&self) -> &ManagedApiMetadata

Returns the API metadata.

pub fn is_lockstep(&self) -> bool

Returns true if the API is lockstep.

pub fn is_versioned(&self) -> bool

Returns true if the API is versioned.

pub fn allow_trivial_changes_for_latest(self) -> Self

Allows trivial changes (doc updates, type renames) for the latest blessed version without requiring a version bump.

By default, the latest blessed version requires bytewise equality between blessed and generated documents. This prevents trivial changes from accumulating invisibly. Calling this method allows semantic-only checking for all versions, including the latest.

pub fn allows_trivial_changes_for_latest(&self) -> bool

Returns true if trivial changes are allowed for the latest version.

pub fn with_git_stub_storage(self) -> Self

Enables Git stub storage for this API, overriding the global setting.

When enabled, non-latest blessed API versions are stored as .gitstub files containing a Git stub instead of full JSON files.

pub fn disable_git_stub_storage(self) -> Self

Disables Git stub storage for this API, overriding the global setting.

pub fn uses_git_stub_storage(&self) -> Option<bool>

Returns the Git stub storage setting for this API.

  • None: use the global setting.
  • Some(true): Git stub storage is enabled for this API.
  • Some(false): Git stub storage is disabled for this API.
pub fn with_extra_validation<F>(self, f: F) -> Self
where F: Fn(&OpenAPI, ValidationContext<'_>) + Send + Sync + 'static,

Sets extra validation to perform on the OpenAPI document.

For versioned APIs, extra validation is performed on all versions, including blessed ones. You may want to skip performing validation on blessed versions, though, because they’re immutable. To do so, use ValidationContext::is_blessed.