ManagedApiConfig

Struct ManagedApiConfig 

pub struct ManagedApiConfig {
    pub ident: &'static str,
    pub versions: Versions,
    pub title: &'static str,
    pub metadata: ManagedApiMetadata,
    pub api_description: fn() -> Result<ApiDescription<StubContext>, ApiDescriptionBuildErrors>,
    pub extra_validation: Option<fn(&OpenAPI, ValidationContext<'_>)>,
}
Describes an API managed by the Dropshot API manager.

Each API listed within a ManagedApiConfig forms a unit managed by the Dropshot API manager.

Fields

ident: &'static str

The API-specific part of the filename that’s used for API descriptions

This string is sometimes used as an identifier for developers.

versions: Versions

how this API is versioned

title: &'static str

title of the API (goes into OpenAPI spec)

metadata: ManagedApiMetadata

metadata about the API

api_description: fn() -> Result<ApiDescription<StubContext>, ApiDescriptionBuildErrors>

The API description function, typically a reference to stub_api_description

This is used to generate the OpenAPI document that matches the current server implementation.

extra_validation: Option<fn(&OpenAPI, ValidationContext<'_>)>

Extra validation to perform on the OpenAPI document, if any.

For versioned APIs, extra validation is performed on all versions, including blessed ones. You may want to skip performing validation on blessed versions, though, because they’re immutable. To do so, use ValidationContext::is_blessed.