pub struct ManagedApis { /* private fields */ }Expand description
Describes the Rust-defined configuration for all of the APIs managed by this tool.
This is repo-specific state that’s passed into the OpenAPI manager.
Implementations
Sourceimpl ManagedApis
impl ManagedApis
Sourcepub fn new<I>(api_list: I) -> Result<ManagedApis>
pub fn new<I>(api_list: I) -> Result<ManagedApis>
Constructs a new ManagedApis instance from a list of API
configurations.
This is the main entry point for creating a new ManagedApis instance.
Accepts any iterable of items that can be converted into ManagedApi,
including Vec<ManagedApiConfig> and Vec<ManagedApi>.
Sourcepub fn with_unknown_apis<I, S>(self, apis: I) -> Self
pub fn with_unknown_apis<I, S>(self, apis: I) -> Self
Adds the given API identifiers (without the ending .json) to the list
of unknown APIs.
By default, if an unknown .json file is encountered within the OpenAPI
directory, a failure is produced. Use this method to produce a warning
for an allowlist of APIs instead.
Sourcepub fn with_validation<F>(self, validation: F) -> Self
pub fn with_validation<F>(self, validation: F) -> Self
Sets a validation function to be used for all APIs.
This function will be called for each API document. The
ValidationContext can be used to report errors, as well as extra
files for which the contents need to be compared with those on disk.
Sourcepub fn with_git_stub_storage(self) -> Self
pub fn with_git_stub_storage(self) -> Self
Enables Git stub storage for older blessed API versions.
When enabled, non-latest blessed API versions are stored as .gitstub
files containing a Git stub instead of full JSON files. This allows
for Git (including the GitHub web UI) to detect changed OpenAPI
documents as renames, but Git history is required to be present to read
older versions.
Individual APIs can override this setting using
ManagedApi::with_git_stub_storage or
ManagedApi::disable_git_stub_storage.
Sourcepub fn unknown_apis(&self) -> &BTreeSet<ApiIdent>
pub fn unknown_apis(&self) -> &BTreeSet<ApiIdent>
Returns the set of unknown APIs.