Modules
- test_
util - Test utilities for the Dropshot API manager.
Structs
- App
- Manage OpenAPI documents for this repository.
- Environment
- Configuration for the Dropshot API manager.
- Managed
Api - Describes an API managed by the Dropshot API manager.
- Managed
ApiConfig - Describes an API managed by the Dropshot API manager.
- Managed
Apis - Describes the Rust-defined configuration for all of the APIs managed by this tool.
Constants
- FAILURE_
EXIT_ CODE - Exit code which indicates that one or more failures occurred.
- NEEDS_
UPDATE_ EXIT_ CODE - Exit code which indicates that local files are out-of-date.