pub struct ManagedApis { /* private fields */ }Expand description
Describes the Rust-defined configuration for all of the APIs managed by this tool.
This is repo-specific state that’s passed into the OpenAPI manager.
Implementations
Sourceimpl ManagedApis
impl ManagedApis
Sourcepub fn new(api_list: Vec<ManagedApiConfig>) -> Result<ManagedApis>
pub fn new(api_list: Vec<ManagedApiConfig>) -> Result<ManagedApis>
Constructs a new ManagedApis instance from a list of API
configurations.
This is the main entry point for creating a new ManagedApis instance.
Sourcepub fn with_unknown_apis<I, S>(self, apis: I) -> Self
pub fn with_unknown_apis<I, S>(self, apis: I) -> Self
Adds the given API identifiers (without the ending .json) to the list
of unknown APIs.
By default, if an unknown .json file is encountered within the OpenAPI
directory, a failure is produced. Use this method to produce a warning
for an allowlist of APIs instead.
Sourcepub fn with_validation(
self,
validation: fn(&OpenAPI, ValidationContext<'_>),
) -> Self
pub fn with_validation( self, validation: fn(&OpenAPI, ValidationContext<'_>), ) -> Self
Sets a validation function to be used for all APIs.
This function will be called for each API document. The
ValidationContext can be used to report errors, as well as extra
files for which the contents need to be compared with those on disk.
Sourcepub fn validation(&self) -> Option<fn(&OpenAPI, ValidationContext<'_>)>
pub fn validation(&self) -> Option<fn(&OpenAPI, ValidationContext<'_>)>
Returns the validation function for all APIs.
Sourcepub fn unknown_apis(&self) -> &BTreeSet<ApiIdent>
pub fn unknown_apis(&self) -> &BTreeSet<ApiIdent>
Returns the set of unknown APIs.