pub struct ManagedApis { /* private fields */ }Expand description
Describes the Rust-defined configuration for all of the APIs managed by this tool.
This is repo-specific state that’s passed into the OpenAPI manager.
Implementations
Sourceimpl ManagedApis
impl ManagedApis
pub fn new(api_list: Vec<ManagedApiConfig>) -> Result<ManagedApis>
Sourcepub fn with_validation(
self,
validation: fn(&OpenAPI, ValidationContext<'_>),
) -> Self
pub fn with_validation( self, validation: fn(&OpenAPI, ValidationContext<'_>), ) -> Self
Sets a validation function to be used for all APIs.
This function will be called for each API document. The
ValidationContext can be used to report errors, as well as extra
files for which the contents need to be compared with those on disk.
Sourcepub fn validation(&self) -> Option<fn(&OpenAPI, ValidationContext<'_>)>
pub fn validation(&self) -> Option<fn(&OpenAPI, ValidationContext<'_>)>
Returns the validation function for all APIs.
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn iter_apis(&self) -> impl Iterator<Item = &ManagedApi> + '_
pub fn api(&self, ident: &ApiIdent) -> Option<&ManagedApi>